==> blender-2.31.tar.gz: blender-2.31/source/gameengine/Expressions/KX_HashedPtr.h <==
/**
 * $Id: KX_HashedPtr.h,v 1.5 2002/12/27 13:10:39 mein Exp $
 *
 * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. The Blender
 * Foundation also sells licenses for use in proprietary software under
 * the Blender License.  See http://www.blender.org/BL/ for information
 * about this.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL/BL DUAL LICENSE BLOCK *****
 */
#ifndef __KX_HASHEDPTR
#define __KX_HASHEDPTR

unsigned int			KX_Hash(unsigned int inDWord);

class CHashedPtr
{
	void* m_valptr;

public:
	CHashedPtr(void* val);

	unsigned int hash() const;

	inline friend bool operator ==( const CHashedPtr & rhs,const CHashedPtr & lhs)
	{
		return rhs.m_valptr == lhs.m_valptr;
	}	
};

#endif //__KX_HASHEDPTR

==> blender-2.44.tar.gz: blender-2.44/source/gameengine/Expressions/KX_HashedPtr.h <==
/**
 * $Id: KX_HashedPtr.h,v 1.7 2005/11/28 06:51:53 erwin Exp $
 *
 * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. The Blender
 * Foundation also sells licenses for use in proprietary software under
 * the Blender License.  See http://www.blender.org/BL/ for information
 * about this.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL/BL DUAL LICENSE BLOCK *****
 */
#ifndef __KX_HASHEDPTR
#define __KX_HASHEDPTR

unsigned int			KX_Hash(void * inDWord);

class CHashedPtr
{
	void* m_valptr;

public:
	CHashedPtr(void* val);

	unsigned int hash() const;

	inline friend bool operator ==( const CHashedPtr & rhs,const CHashedPtr & lhs)
	{
		return rhs.m_valptr == lhs.m_valptr;
	}	
};

#endif //__KX_HASHEDPTR
